summary refs log tree commit diff stats
path: root/plugins/sysinfo/sysinfo.cpp
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-21 06:40:28 +0200
committerBerke Viktor <bviktor@hexchat.org>2012-10-21 06:40:28 +0200
commitcb891a9732d77dde425052b6d11dc8024492e80a (patch)
tree8ee9aab170fd12b4a541dd201d8200513091262d /plugins/sysinfo/sysinfo.cpp
parentc54cd4181b9d4b49768c56a47655dbea1a9553b7 (diff)
Rename WinSys on the code level
Diffstat (limited to 'plugins/sysinfo/sysinfo.cpp')
-rw-r--r--plugins/sysinfo/sysinfo.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins/sysinfo/sysinfo.cpp b/plugins/sysinfo/sysinfo.cpp
index d15118fe..5cb4b766 100644
--- a/plugins/sysinfo/sysinfo.cpp
+++ b/plugins/sysinfo/sysinfo.cpp
@@ -28,7 +28,7 @@
 #include "xchat-plugin.h"
 
 static xchat_plugin *ph;   /* plugin handle */
-static char name[] = "WinSys";
+static char name[] = "SysInfo";
 static char desc[] = "Display info about your hardware and OS";
 static char version[] = "1.1";
 static int firstRun;
@@ -352,7 +352,7 @@ getWmiInfo (int mode)
 static int
 printInfo (char *word[], char *word_eol[], void *user_data)
 {
 	/* query WMI info only at the first time WinSys is called, then cache it to save time */
 	if (firstRun)
 	{
 		xchat_printf (ph, "%s first execution, querying and caching WMI info...\n", name);
@@ -364,7 +364,7 @@ printInfo (char *word[], char *word_eol[], void *user_data)
 	if (xchat_list_int (ph, NULL, "type") >= 2)
 	{
 		/* uptime will work correctly for up to 50 days, should be enough */
-		xchat_commandf (ph, "ME ** WinSys ** Client: HexChat %s (x%d) ** OS: %s ** CPU: %s (%s) ** RAM: %s ** VGA: %s ** Uptime: %.2f Hours **",
+		xchat_commandf (ph, "ME ** SysInfo ** Client: HexChat %s (x%d) ** OS: %s ** CPU: %s (%s) ** RAM: %s ** VGA: %s ** Uptime: %.2f Hours **",
 			xchat_get_info (ph, "version"),
 			getCpuArch (),
 			wmiOs,
@@ -397,8 +397,8 @@ xchat_plugin_init (xchat_plugin *plugin_handle, char **plugin_name, char **plugi
 
 	firstRun = 1;
 
-	xchat_hook_command (ph, "WINSYS", XCHAT_PRI_NORM, printInfo, NULL, NULL);
-	xchat_command (ph, "MENU -ietc\\system.png ADD \"Window/Display System Info\" \"WINSYS\"");
+	xchat_hook_command (ph, "SYSINFO", XCHAT_PRI_NORM, printInfo, NULL, NULL);
+	xchat_command (ph, "MENU -ietc\\system.png ADD \"Window/Display System Info\" \"SYSINFO\"");
 
 	xchat_printf (ph, "%s plugin loaded\n", name);
@@ -352,7 +352,7 @@ getWmiInfo (int mode)
 printInfo (char *word[], char *word_eol[], void *user_data)
 {
-	/* query WMI info only at the first time WinSys is called, then cache it to save time */
+	/* query WMI info only at the first time SysInfo is called, then cache it to save time */
 	if (firstRun)
 	{